// ===========Oooo==========================================Oooo========
// =  Copyright (C) 2014 Shanghai Gowin Semiconductor Technology Co.,Ltd.
// =                     All rights reserved.
// =====================================================================
//
//  __      __      __
//  \ \    /  \    / /   [File name   ] colorbar_gen.v
//   \ \  / /\ \  / /    [Description ] NA
//    \ \/ /  \ \/ /     [Timestamp   ] Fri Feb 27 09:30:00 2016
//     \  /    \  /      [version     ] 1.0
//      \/      \/       
// --------------------------------------------------------------------
// Code Revision History :
// --------------------------------------------------------------------
// Ver: | Author  |Mod. Date |Changes Made:
// V1.0 | Johnson |27/02/16  |Initial version
// ===========Oooo==========================================Oooo========
//`define SIM
`timescale 1ns/1ps
module colorbar_gen #
(parameter H_ACT = 1280
,parameter H_TOL = 1664
`ifdef SIM
,parameter V_ACT = 10
,parameter V_TOL = 25
`else
,parameter V_ACT = 720
,parameter V_TOL = 748
`endif
,parameter H_FP = 64
,parameter H_SYC = 128
,parameter V_FP = 3
,parameter V_SYC = 5
,parameter MODE = 0 //0 = colorbar, 1 = walking 1's
)
(input clk
,input rst_n
,output fv
,output lv
,output hsync
,output vsync
,output [23:0] data
);

reg [11:0] pix_cnt;
reg [11:0] line_cnt;
reg [11:0] color_cnt;	
reg lv_r;
reg fv_r;
reg hsync_r;
reg vsync_r;

always @(posedge clk or negedge rst_n) begin
    if(!rst_n) begin
        pix_cnt <= 'b0;
        line_cnt <= 'b0;
        lv_r <= 'b0;
        fv_r <= 'b0;
        hsync_r <= 'b0;
        vsync_r <= 'b0;
    end else begin
    	  pix_cnt <= pix_cnt < H_TOL - 1 ? pix_cnt + 1 : 'b0;
    	  line_cnt <= pix_cnt == H_TOL - 1 && line_cnt == V_TOL - 1 ? 'b0 : 
    	              pix_cnt == H_TOL - 1 && line_cnt < V_TOL - 1 ? line_cnt + 1 : line_cnt;  	  
    	  lv_r <= pix_cnt > 0 && pix_cnt <= H_ACT && line_cnt < V_ACT; 
       	fv_r <= line_cnt >= 0 && line_cnt < V_ACT; 	            
       	hsync_r <= pix_cnt > H_ACT + H_FP  && pix_cnt <= H_ACT + H_FP + H_SYC; 
        vsync_r <= line_cnt >= V_ACT + V_FP && line_cnt < V_ACT + V_FP + V_SYC;             
    end  	
end

assign lv = lv_r;
assign fv = fv_r;
assign hsync = hsync_r;
assign vsync = vsync_r;

always @(posedge clk or negedge rst_n)
    if(!rst_n)
         color_cnt <= 0;
    else
         color_cnt <= lv ? color_cnt+1 : 0;

generate
    if (MODE==1)	                 	         
        assign data = color_cnt;
    else 
        assign data = color_cnt < 320 ? {8'hFF, 8'h00, 8'h00} :
                      color_cnt < 640 ? {8'h00, 8'hFF, 8'h00} : 

                      color_cnt < 960 ? {8'h00, 8'h00, 8'hFF} :  

                      color_cnt < 1280 ? {8'hFF, 8'hff, 8'hff} : {8'h00, 8'h00, 8'h00};

        
endgenerate   

endmodule