`timescale 1 ns/ 1 ps
module top 
(input pix_clk
,output TCLK_out_p
,output TCLK_out_n
,output T0_out_p
,output T1_out_p
,output T2_out_p
,output T3_out_p
,output T0_out_n
,output T1_out_n
,output T2_out_n
,output T3_out_n
);
       
wire t_DE;
wire t_Hsync;
wire t_Vsync;
wire [7:0] t_R;
wire [7:0] t_G;
wire [7:0] t_B;
wire [23:0] pix_data;
wire [6:0] tx_a ;
wire [6:0] tx_b ;
wire [6:0] tx_c ;
wire [6:0] tx_d ;
wire [6:0] tx_a_inv ;
wire [6:0] tx_b_inv ;
wire [6:0] tx_c_inv ;
wire [6:0] tx_d_inv ;
reg [6:0] cnt=0;
wire rst_n;

always @(posedge pix_clk) begin
	  cnt <= cnt == 127 ? cnt : cnt + 1'b1;
end	

assign rst_n = cnt == 127 ? 1 : 0;

colorbar_gen 
u_colorbar_gen
(.clk      (pix_clk)
,.rst_n    (rst_n)
,.fv       ()
,.lv       (t_DE)
,.hsync    (t_Hsync)
,.vsync    (t_Vsync)
,.data     (pix_data)
);

assign t_R = pix_data[23:16];
assign t_G = pix_data[15:8];
assign t_B = pix_data[7:0];

assign  tx_d = {t_R[6], t_R[7], t_G[6], t_G[7], t_B[6], t_B[7], 1'b1};
assign  tx_c = {t_B[2], t_B[3], t_B[4], t_B[5], t_Hsync, t_Vsync, t_DE};
assign  tx_b = {t_G[1], t_G[2], t_G[3], t_G[4], t_G[5], t_B[0], t_B[1]};
assign  tx_a = {t_R[0], t_R[1], t_R[2], t_R[3], t_R[4], t_R[5], t_G[0]};

assign  tx_d_inv = {tx_d[0],tx_d[1],tx_d[2],tx_d[3],tx_d[4],tx_d[5],tx_d[6],tx_d[7]};
assign  tx_c_inv = {tx_c[0],tx_c[1],tx_c[2],tx_c[3],tx_c[4],tx_c[5],tx_c[6],tx_c[7]};
assign  tx_b_inv = {tx_b[0],tx_b[1],tx_b[2],tx_b[3],tx_b[4],tx_b[5],tx_b[6],tx_b[7]};
assign  tx_a_inv = {tx_a[0],tx_a[1],tx_a[2],tx_a[3],tx_a[4],tx_a[5],tx_a[6],tx_a[7]};


LVDS_7_to_1_TX tx_inst
(.RST_Tx   (~rst_n)       
,.eclk     (eclk)     //PLL   
,.sync_clk (pix_clk)   
,.stop     (0)                           
,.T0_in    (tx_a)     
,.T1_in    (tx_b)     
,.T2_in    (tx_c)     
,.T3_in    (tx_d)             
,.TCLK_out_p (TCLK_out_p) 
,.TCLK_out_n (TCLK_out_n) 
,.T0_out_p   (T0_out_p)   
,.T1_out_p   (T1_out_p)   
,.T2_out_p   (T2_out_p)   
,.T3_out_p   (T3_out_p)     
,.T0_out_n   (T0_out_n)   
,.T1_out_n   (T1_out_n)   
,.T2_out_n   (T2_out_n)   
,.T3_out_n   (T3_out_n)  
);
    
PLL pll_inst (
    .CLKOUT(eclk),
    .LOCK(lock),
    .CLKOUTP(),
    .CLKOUTD(),
    .CLKOUTD3(),
    .RESET(0),
    .RESET_P(0),
    .RESET_I(0),
    .RESET_S(0),
    .CLKIN(pix_clk),
    .CLKFB(0),
    .FBDSEL({0,0,0,0,0,0}),
    .IDSEL({0,0,0,0,0,0}),
    .ODSEL({0,0,0,0,0,0}),
    .PSDA({0,0,0,0}),
    .DUTYDA({0,0,0,0}),
    .FDLY({1,1,1,1})
);

defparam pll_inst.FCLKIN = "80";                      
defparam pll_inst.DYN_IDIV_SEL = "false";             
defparam pll_inst.IDIV_SEL = 1;                       
defparam pll_inst.DYN_FBDIV_SEL = "false";            
defparam pll_inst.FBDIV_SEL = 6;  
defparam pll_inst.DYN_ODIV_SEL= "false";                    
defparam pll_inst.ODIV_SEL = 4;                       
defparam pll_inst.PSDA_SEL = "0100";                  
defparam pll_inst.DYN_DA_EN = "false";                
defparam pll_inst.DUTYDA_SEL = "1000";                
defparam pll_inst.CLKOUT_FT_DIR = 1'b1;               
defparam pll_inst.CLKOUTP_FT_DIR = 1'b1;              
defparam pll_inst.CLKOUT_DLY_STEP = 0;                
defparam pll_inst.CLKOUTP_DLY_STEP = 0;               
defparam pll_inst.CLKFB_SEL = "internal";             
defparam pll_inst.CLKOUT_BYPASS = "false";            
defparam pll_inst.CLKOUTP_BYPASS = "false";           
defparam pll_inst.CLKOUTD_BYPASS = "false";           
defparam pll_inst.DYN_SDIV_SEL = 2;                   
defparam pll_inst.CLKOUTD_SRC = "CLKOUT";             
defparam pll_inst.CLKOUTD3_SRC = "CLKOUT";            
defparam pll_inst.DEVICE = "GW2A-18";                  
endmodule
